==> mx2g_1.1.1.tar.gz: mx-1.1.1/libmyriexpress/mx_cancel.c <==
/*************************************************************************
 * The contents of this file are subject to the MYRICOM MYRINET          *
 * EXPRESS (MX) NETWORKING SOFTWARE AND DOCUMENTATION LICENSE (the       *
 * "License"); User may not use this file except in compliance with the  *
 * License.  The full text of the License can found in LICENSE.TXT       *
 *                                                                       *
 * Software distributed under the License is distributed on an "AS IS"   *
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See  *
 * the License for the specific language governing rights and            *
 * limitations under the License.                                        *
 *                                                                       *
 * Copyright 2003 - 2004 by Myricom, Inc.  All rights reserved.          *
 *************************************************************************/

static const char __idstring[] = "@(#)$Id: mx_cancel.c,v 1.37 2005/08/08 22:49:39 eugene Exp $";
 
#include "mx_auto_config.h"
#include "myriexpress.h"
#include "mx__lib_types.h"
#include "mx__request.h"

MX_FUNC(mx_return_t)
mx_cancel(mx_endpoint_t endpoint, mx_request_t *reqp, uint32_t *result)
{
  union mx_request *req;
  union mx_request *x = *reqp;
  
  MX__MUTEX_LOCK(&endpoint->lock);
  /* Search in the send request queue and recv request queue. */
  
  switch (x->basic.type) {
  case MX__REQUEST_TYPE_RECV:
  case MX__REQUEST_TYPE_RECV_LARGE:
    for (req = endpoint->recv_reqq.basic.next;
	 req != &endpoint->recv_reqq;
	 req = req->basic.next) {
      if (x == req) {
	mx__spliceout_request(&endpoint->recv_reqq, req);
	*reqp = 0;
	*result = 1;
	mx__rl_free(&endpoint->req_lookaside, req);
	goto done;
      }
    }
    *result = 0;
    break;
  default:
    mx_printf("mx_cancel call on req type %d\n", x->basic.type);
    mx_fatal("mx_cancel failure\n");
  }

 done:
  MX__MUTEX_UNLOCK(&endpoint->lock);
  return MX_SUCCESS;
}

==> mx2g_1.1.4.tar.gz: mx-1.1.4/libmyriexpress/mx_cancel.c <==
/*************************************************************************
 * The contents of this file are subject to the MYRICOM MYRINET          *
 * EXPRESS (MX) NETWORKING SOFTWARE AND DOCUMENTATION LICENSE (the       *
 * "License"); User may not use this file except in compliance with the  *
 * License.  The full text of the License can found in LICENSE.TXT       *
 *                                                                       *
 * Software distributed under the License is distributed on an "AS IS"   *
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See  *
 * the License for the specific language governing rights and            *
 * limitations under the License.                                        *
 *                                                                       *
 * Copyright 2003 - 2004 by Myricom, Inc.  All rights reserved.          *
 *************************************************************************/

static const char __idstring[] = "@(#)$Id: mx_cancel.c,v 1.37.4.1 2006/04/13 17:50:15 bgoglin Exp $";
 
#include "mx_auto_config.h"
#include "myriexpress.h"
#include "mx__lib_types.h"
#include "mx__request.h"

MX_FUNC(mx_return_t)
mx_cancel(mx_endpoint_t endpoint, mx_request_t *reqp, uint32_t *result)
{
  union mx_request *req;
  union mx_request *x = *reqp;
  
  MX__MUTEX_LOCK(&endpoint->lock);
  /* Search in the send request queue and recv request queue. */
  
  switch (x->basic.type) {
  case MX__REQUEST_TYPE_RECV:
  case MX__REQUEST_TYPE_RECV_LARGE:
    for (req = endpoint->recv_reqq.basic.next;
	 req != &endpoint->recv_reqq;
	 req = req->basic.next) {
      if (x == req) {
	mx__spliceout_request(&endpoint->recv_reqq, req);
	*reqp = 0;
	*result = 1;
	mx__rl_free(&endpoint->req_lookaside, req);
	goto done;
      }
    }
    *result = 0;
    break;
  default:
    mx_printf("mx_cancel call on req type %d\n", x->basic.type);
    mx_fatal("mx_cancel failure");
  }

 done:
  MX__MUTEX_UNLOCK(&endpoint->lock);
  return MX_SUCCESS;
}
